@@ -62,7 +62,7 @@ class GitCliVcsProvider(VcsProvider, CliRunnerMixin):
         except CalledProcessError as cpe:
             raise VcsProviderError(
                 f"Failed to check if {self.current_path} is a clean "
-                f"git repository."
+                f"git repository. Reason: {cpe.stderr}"
             ) from cpe
 
     def check_in_items(self, message: str, *files: Tuple[Path, ...]) -> None:
@@ -85,21 +85,21 @@ class GitCliVcsProvider(VcsProvider, CliRunnerMixin):
             f_args = ",".join([str(f) for f in files])
             raise VcsProviderError(
                 f"Failed to check in items in {self.current_path} "
-                f"using {f_args}."
+                f"using {f_args}. Reason: {cpe.stderr}"
             ) from cpe
 
     def create_tag_from_string(self, version_formatted: str) -> None:
         try:
             _ = self.run(
                 self.git_executable_path,
-                ("tag", f"v{version_formatted}"),
+                ("tag", version_formatted),
                 raise_on_exit=True,
                 cwd=self.current_path,
             )
         except CalledProcessError as cpe:
             raise VcsProviderError(
-                f"Failed to create tag f{version_formatted} "
-                f"in {self.current_path}."
+                f"Failed to create tag {version_formatted} "
+                f"in {self.current_path}. Reason: {cpe.stderr}"
             ) from cpe
 
     def get_most_recent_tag(self) -> Optional[Version]:
@@ -112,7 +112,7 @@ class GitCliVcsProvider(VcsProvider, CliRunnerMixin):
             )
         except CalledProcessError as cpe:
             raise VcsProviderError(
-                "Failed to receive most recent tag"
+                f"Failed to receive most recent tag. . Reason: {cpe.stderr}"
             ) from cpe
 
         if output.strip() == "":
@@ -140,7 +140,8 @@ class GitCliVcsProvider(VcsProvider, CliRunnerMixin):
             return int(output)
         except CalledProcessError as cpe:
             raise VcsProviderError(
-                "Failed to receive number of commits since last tag."
+                f"Failed to receive number of commits since last tag."
+                f" Reason: {cpe.stderr}"
             ) from cpe
 
     def get_changes_not_checked_in(self) -> int:
@@ -155,7 +156,8 @@ class GitCliVcsProvider(VcsProvider, CliRunnerMixin):
             return len(lines)
         except CalledProcessError as cpe:
             raise VcsProviderError(
-                "Failed to receive number of changes that are not committed"
+                f"Failed to receive number of changes that are not committed."
+                f" Reason: {cpe.stderr}"
             ) from cpe
 
 
